#
# spec file for package vnstat
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vnstat
Version:        2.13
Release:        1.1
Summary:        Network Traffic Monitor
License:        GPL-2.0-only
Group:          Productivity/Networking/Diagnostic
URL:            https://humdi.net/vnstat
Source:         https://humdi.net/vnstat/vnstat-%{version}.tar.gz
Source2:        vnstat-cgi.conf
Source3:        vnstat-create-db.sh
Source4:        vnstat.init
Source98:       https://humdi.net/vnstat/vnstat-%{version}.tar.gz.asc#/%{name}-%{version}.tar.gz.sig
Source99:       %{name}.keyring
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  check-devel
BuildRequires:  gd-devel
BuildRequires:  glibc-devel
BuildRequires:  sqlite3-devel
Requires:       %{_bindir}/killall
Requires:       /bin/ls
Requires:       /bin/su
Provides:       group(vnstat)
Provides:       user(vnstat)
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}

%description
vnStat is a network traffic monitor for Linux that keeps a log of
daily network traffic for the selected interface(s). vnStat isn't a
packet sniffer. The traffic information is analyzed from the /proc
filesystem, so vnStat can be used without root permissions.

%package cgi
Summary:        Graph Visualization CGI Script for %{name}
Group:          Productivity/Networking/Diagnostic
Requires:       %{name} = %{version}
Recommends:     apache2

%description cgi
vnStat is a network traffic monitor for Linux that keeps a log of
daily network traffic for the selected interface(s). vnStat isn't a
packet sniffer. The traffic information is analyzed from the /proc
filesystem, so vnStat can be used without root permissions.

This package contains a CGI script that visualizes graphs of the
collected traffic statistics.

%prep
%setup -q
# Add user and group to the systemd service.
sed -i 's/\(\[Service\]\)/\1\nUser=vnstat\nGroup=vnstat/' examples/systemd/simple/vnstat.service

%build
autoreconf -fi
%configure
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_localstatedir}/lib/vnstat/

install -Dm 0755 examples/vnstat.cgi %{buildroot}/srv/vnstat/vnstat.cgi
install -Dm 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/apache2/conf.d/vnstat.conf

install -Dm 0755 %{SOURCE3} %{buildroot}%{_bindir}/vnstat-create-db

install -Dm 0644 examples/systemd/simple/vnstat.service %{buildroot}%{_unitdir}/vnstatd.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcvnstatd

%check
%make_build check

%pre
%{_sbindir}/groupadd -r vnstat &> /dev/null || :
%{_sbindir}/useradd -g vnstat -s /bin/sh -r -c "vnstat daemon" -d %{_localstatedir}/lib/vnstat vnstat &>/dev/null ||:
%service_add_pre vnstatd.service

%post
%service_add_post vnstatd.service

%preun
%service_del_preun vnstatd.service

%postun
%service_del_postun vnstatd.service

%files
%doc CHANGES FAQ README UPGRADE
%license COPYING
%config(noreplace) %{_sysconfdir}/vnstat.conf
%{_bindir}/vnstat-create-db
%{_bindir}/vnstat
%{_sbindir}/vnstatd
%{_sbindir}/rcvnstatd
%{_unitdir}/vnstatd.service
%{_mandir}/man1/vnstat.1%{?ext_man}
%{_mandir}/man8/vnstatd.8%{?ext_man}
%{_mandir}/man5/vnstat.conf.5%{?ext_man}
%attr(0755,vnstat,root) %{_localstatedir}/lib/vnstat

%files cgi
%dir %{_sysconfdir}/apache2/
%dir %{_sysconfdir}/apache2/conf.d/
%config(noreplace) %{_sysconfdir}/apache2/conf.d/vnstat.conf
%{_bindir}/vnstati
%{_mandir}/man1/vnstati.1%{?ext_man}
/srv/vnstat/

%changelog
* Sat Feb  8 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 2.13
  Fixed
  * Opening of body html tag was missing on some pages in image
    output.
  * example cgi (examples/vnstat.cgi).
  New
  * Add database data merge support as --merge.
  * Add --db for specifying database file for queries (vnstat and
    vnstati).
  * Add exit status 2 options to --alert for making it possible to
    differentiate alerts from errors (exit status 1).
  * Add --dbiflist also to vnstati command.
  * Image output example cgi (examples/vnstat.cgi) improvements.
    + Remove dependency to vnstat command.
    + Add option for selecting how many images are shown per row
    on the index + page when the database has more than one
    interface.
    + Add option for selecting which image output is used on the
    index page + when the database has more than one interface.
    + Add options for selecting which interfaces are shown or
    hidden from the index page without disabling access to all
    interface specific page when the database has more than one
    interface.
    + Harmonize layout style between pages.
* Sun Feb  4 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.12:
  * Fixes:
  - QueryMode documentation in configuration file didn't match
    implementation or man page description
  - Daemon didn't try to import legacy databases when --noadd
    was used and no current version database initially existed
    resulting in the process exiting even when something could
    have been done
  - Daemon didn't try to import legacy databases when --initdb
    was used and no current version database initially existed,
    this behaviour can still be enabled by using --noadd in
    combination with --initdb
  - Using --nodaemon and --initdb at the same time didn't result
    in an error being shown
  * New
  - Add 95th percentile output as --95th, also available via
  - -alert, --json, --xml and image output, requires
    5MinuteHours configuration to be set to at least 744 for
    storing all the necessary data
  - Add --json support for --alert
  - Database queries resulting in error exit with status 1
  - Show spinning animation at the beginning of -l / --live
    output line, visibility configurable using LiveSpinner
    configuration option
  - Add -ic / --invert-colors option to image output for
    facilitating for example dark mode switching without needing
    to have multiple separate color configurations
  - Add dark mode option to image output example cgi
    (examples/vnstat.cgi)
  - Add option 4 to QueryMode for selecting summary output of
    single interface regardless of the number of interfaces in
    the database
  - Add optional mode parameter to -q / --query for overriding
    QueryMode for summary output and for enabling control of
    summary output style regardless of the number of interfaces
    in the database
  - Add --startempty option to daemon for starting and keeping
    the daemon running even if no interfaces were discovered and
    the database is empty
  - Add --noremove option to daemon for disabling the automatic
    removal of interfaces from database that aren't currently
    visible and haven't seen any traffic
  - Add third mode option to --iflist and --dbiflist for getting
    only the interface count as output
- Add Provides for group and user names as required by rpm 4.19.
- Drop conditionals supporting EOL openSUSE versions.
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.11
  Fixed
  * Database queries worked only if SQLite double-quoted string (DQS)
    feature (https://www.sqlite.org/quirks.html#dblquote) was enabled
  * Disabling data resolutions in data retention configuration didn't result
    in possibly existing database entries getting removed from the database
  * Disabling data resolutions in data retention configuration didn't result
    in the data resolution getting disabled but instead storing data forever
  * "expr: syntax error" during configure in BSD (pull request by namtsui)
  * Image output summary would show only "no data available" text in case of
    zero total traffic even when the historical data of no traffic could have
    been shown instead
  * Image output "-o -" content could get corrupted due to info, warning and
    error messages also using stdout, configuration file warnings being the
    most likely source, now uses stderr in image output
  * Configuration validation was too heavily limiting and enforcing image
    output 5 minute graph related configuration options for combinations that
    would have resulted in usable images
  New
  * Database cleanup has been changed to interpret data retention
    configuration as number of entries to be kept instead of calendar time,
    this restores the behaviour to similar as it was up to version 1.18, the
    difference is visible only on systems that aren't powered all the time
  * Database is vacuumed during daemon startup and reload, behaviour is
    configurable using VacuumOnStartup and VacuumOnHUPSignal configuration
    options
  * Add configuration option InterfaceOrder for controlling the interface
    order in outputs with multiple interfaces
  * Used data retention configuration is made visible during daemon startup
    and after configuration reloads
  * Daemon will no longer start if all data resolutions have been disabled
    in the configuration file
  * SQLite version is visible in --version outputs
  Notes
  * "Not enough data available yet." message has been replaced with
    "No data. Timestamp of last update is same YYYY-MM-DD HH:MM:SS as of
    database creation." to better explain the reason why there's nothing to
    show, this message is expected to disappear within configured
    SaveInterval if the interface is active
* Thu Dec  8 2022 Thorsten Kukuk <kukuk@suse.com>
- Drop vnstat-if.sh, the used options are not supported anymore by
  vnstat and only create error messages
* Sat Oct 22 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.10:
  Fixed
  * Image output of 5 minute graph wasn't possible if data
    retention of the 5 minute time period was configured as
    unlimited.
  * Estimates and average rates weren't calculated correctly for
    daily, monthly and yearly time periods when monitoring of the
    interface had been started during the ongoing time period.
  * Estimates weren't being shown in summary output when
    OutputStyle or --style was configured with a value less than 2.
  * Alignment of column header in short output wasn't correct when
    OutputStyle or --style was configured with the value 0 (vnstat)
  New
  * Support input of more than 31 characters in interface name when
    using interface1+interface2 syntax data merge queries.
  * Support passing --config option multiple times, later files
    override earlier files if settings overlap (vnstat and vnstati)
  * Add configuration option EstimateVisible for controlling the
    visibility of the estimate line.
  * Add configuration option EstimateText for modifying the default
    "estimated" text string when the estimate line is visible.
  * Add --style support to -tr / --traffic output.
  * Add summary option to --json and --xml outputs.
  * Add timestamps to --json and --xml outputs.
  * Add Prometheus compatible metrics endpoint cgi to examples.
    (examples/vnstat-metrics.cgi)
* Mon Jan 24 2022 Dirk Müller <dmueller@suse.com>
- update to 2.9:
  * RescanDatabaseOnSave configuration option wasn't being read from the
    configuration file resulting in the feature always being enabled
  * Hourly graph image output using large fonts didn't correctly fade out
    the x-axis line for hours not having data available
  * Add --alert for producing output and/or specific exit status when
    configured condition and transfer limit is exceeded, can also be used
    for "quota remaining" type of queries depending on used parameters
  * Add configuration option InterfaceMatchMethod which allows configuring
    the possibility of specifying an interface for database queries by using
    its alias instead of system provided interface name, enabled by default
    to support case insensitive matching of the beginning of interface
    aliases (vnstat and vnstati)
  * Image output file extension allows selecting the used image file format
    as long as the used LibGD supports it, PNG is no longer the only option
  * Add configuration option HourlyGraphMode for changing the output mode
    of the graph, 0 = 24 hour sliding window (default, as in previous
    releases), 1 = graph begins from midnight
  * Add mode parameter for -hg / --hoursgraph options for overriding the
    HourlyGraphMode configuration option setting from the command line
  * Add vertical line to image output hourly graph to visualize midnight
  * Add -t / --timestamp options to daemon for enabling timestamps to prints
    when the daemon is running in the foreground attached to a terminal
  * Accept ; as comment character in configuration file in addition to #
  * Comment out keywords which are using default values with ; character in
    provided configuration file and --showconfig output
* Mon Jan 24 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.9:
  Fixed
  * RescanDatabaseOnSave configuration option wasn't being read
    from the configuration file resulting in the feature always
    being enabled.
  * Hourly graph image output using large fonts didn't correctly
    fade out the x-axis line for hours not having data available.
  New
  * Add --alert for producing output and/or specific exit status
    when configured condition and transfer limit is exceeded, can
    also be used for "quota remaining" type of queries depending
    on used parameters.
  * Add configuration option InterfaceMatchMethod which allows
    configuring the possibility of specifying an interface for
    database queries by using its alias instead of system provided
    interface name, enabled by default to support case insensitive
    matching of the beginning of interface aliases (vnstat and
    vnstati).
  * Image output file extension allows selecting the used image
    file format as long as the used LibGD supports it, PNG is no
    longer the only option.
  * Add configuration option HourlyGraphMode for changing the
    output mode of the graph, 0 = 24 hour sliding window (default,
    as in previous releases), 1 = graph begins from midnight.
  * Add mode parameter for -hg / --hoursgraph options for
    overriding the.
  * HourlyGraphMode configuration option setting from the command
    line.
  * Add vertical line to image output hourly graph to visualize
    midnight.
  * Add -t / --timestamp options to daemon for enabling timestamps
    to prints when the daemon is running in the foreground
    attached to a terminal
  * Accept ; as comment character in configuration file in addition
    to "#".
  * Comment out keywords which are using default values with ";"-
    character in provided configuration file and --showconfig
    output.
* Sun Nov 28 2021 Dirk Müller <dmueller@suse.com>
- update to 2.8:
  - Using a combination of --live and --json wasn't flushing stdout after
    each line resulting in buffered output if the output was being piped
  - Image output would fail to show the last line bar graph in list outputs
    if EstimateStyle was 0, BarColumnShowsRate was 1 and the last line had a
    higher traffic rate than other lines
  - Image output didn't correctly horizontally align the "no data available"
    message in 5 minute graph depending on the width of the image
  - Image output related configuration warnings could get shown when image
    output wasn't being used
  - Warnings of mismatches between image output and data retention
    configuration didn't provide relevant details for solving the issues
  - BandwidthDetection was being used for tun interfaces even when the
    Linux kernel had the information hardcoded to 10 Mbit regardless of the
    used real interface, interface specific MaxBW will now be used instead
    or MaxBandwidth as fallback
  - Configured interface specific MaxBW values were getting overridden by
    BandwidthDetection when something could be detected
  - Image output horizontal rx/tx bars often had one pixel too much width in
    the tx section resulting in slightly wrong ratio getting shown
  - Top days list wasn't always sorting entries with exactly the same traffic
    sum using ascending date
  - 64bitInterfaceCounters with value -2 always assumed 32-bit on Linux
    systems until a 64-bit value was seen if kernel headers weren't available
    when binaries were built
  - Add the possibility of specifying an interface without using the
  - i / --iface options (vnstat and vnstati)
  - The daemon can discover added interfaces from the database without
    requiring a restart, configurable with option RescanDatabaseOnSave
  - Add configuration option UseUTC for using UTC as timezone for database
    entries instead of following the system timezone configuration
  - --iflist uses user configured interface specific MaxBW values in the
    output when available instead of showing only the kernel provided
    information when detected
  - Add configuration option AlwaysAddNewInterfaces to expose the daemon
  - -alwaysadd command line option which gains an optional mode parameter
  - Image output uses LibGD filled arc bug workaround only for LibGD
    versions that are known to be broken
  - Image output example cgi (examples/vnstat.cgi) improvements
  - Automatically lists all monitored interfaces instead of requiring the
    list to be filled manually, server name in page title comes from
    hostname command by default
  - Provides links for most available images to more detailed or longer
    versions of each image
  - Allows direct interface specific page access with /interfacename suffix
    for the cgi if the used httpd supports PATH_INFO
  - Page auto refresh can be enabled with configurable interval
* Sun Jun  6 2021 Martin Hauke <mardnh@gmx.de>
- Install examples/systemd/simple/vnstat.service
- Drop not longer needed patch:
  * systemd234.patch
* Sun May 16 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7
  Fixed
  * Possibility of segmentation fault with image list output when
    database existed but no data was available.
  * ./configure output could show invalid install paths with some
    parameter combinations.
  * Columns in text hours graph output could get misaligned if the
    selected system locale used a UTF-8 sequence for the thousands
    separator instead of a single character.
  New
  * Add -5g / --fivegraph options to image output with sizing
    related parameters for the output of a 5 minute resolution bar
    graph
  * Add configuration option SummaryGraph and optional parameter
    for --hsummary and --vsummary for selecting which graph is
    shown next to the summary data in the horizontal and vertical
    summary image outputs.
  * Add --large / --small options and configuration option
    LargeFonts for controlling the image output font size.
  * Add --scale and configuration option ImageScale for scaling the
    image output to a given percent.
  * Add configuration option LineSpacingAdjustment for adjusting
    the line spacing of list format image outputs.
  * Add bar visualizations for traffic estimations in image output
  * Allow writing image output to a filename starting with "-".
  * Add --initdb to daemon for creating a new empty database
    without having the daemon process staying running, doesn't
    discard data if a database already exists.
  * Add configuration option BarColumnShowsRate for having the bar
    column in image list outputs be scaled according to the average
    rate column values when those values are visible, disabled by
    default.
  * Add --dbiflist for getting a list of interfaces in the
    database, both --iflist and --dbiflist also get alternative
    more parseable outputs.
  * Add configuration option for large font output and make 5
    minute resolution graph visible in "vnstat.cgi".
* Thu Oct  1 2020 Peter Varkoly <varkoly@suse.com>
- Adapt mod_authz_host parameter instead of deprecated mod_access_compat
  parametere.
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Mon Jan 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6
  Fixed
  * --json and --xml didn't support having both mode and limit
    parameters defined at the same time as documented, broken since
    previous release
  * Documentation was using a mix of "count" and "limit" for the
    option of limiting the maximum number of shown entries in
    queries
  * Summary image output would segmentation fault when the database
    existed but didn't yet contain any daily or monthly data for
    the selected interface
  New
  * Add --limit as an alternative way for controlling the length
    of outputs
* Tue Jan 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5
  Fixed
  * Automatic interface selection wasn't done for --traffic and
  - -live when the Interface configuration setting was left empty
  * --setalias didn't do anything when used in combination
    with --add
  * -l / --live and -tr default to first interface instead of
    producing an error if a interface merge is requested
* Mon Aug 26 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4
  Fixed
  * Daemon didn't correctly wait when acquiring database lock for
    data write which could result in unnecessary errors and even
    process exit if an external database read operation had exactly
    the same timing as the daemon write operation
  * Move vnstatd man page from section 1 to section 8
  New
  * Add --rename for renaming interfaces already existing the
    database
* Wed Jul 10 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3
  Fixed
  * Traffic rate wasn't being shown for the last entry of most lists
    during the first update of the next period (first SaveInterval
    minutes of each new hour, day, month and year)
  * Systemd example service file could result in database file write
    issues if the used systemd version supported ProtectSystem=strict
    but didn't support StateDirectory
  * Interfaces could end up staying marked as 'disabled' in the
    database even after becoming back active and monitored, only the
    shown status was wrong without resulting in any data loss
  * Some image outputs didn't allocate enough height for the image
    resulting in the last row having less space below it than intended
  New
  * Automatic interface selection when the Interface configuration
    setting is left empty (new default)
  * Add configuration option DatabaseWriteAheadLogging to enable
    SQLite Write-Ahead Logging mode which may provide some disk i/o
    benefits, see https://www.sqlite.org/wal.html for more details and
    note that SQLite 3.22.0 or later is required to support read-only
    operations
  * Add configuration option DatabaseSynchronous for changing the
    SQLite setting of the "synchronous" flag, see
    https://www.sqlite.org/pragma.html#pragma_synchronous for more
    details
  * Show warning in log if writing cached data to database is slow
  * Try database query for up to 5 seconds when database is busy or
    locked instead of giving up immediately
  * Continue daemon process execution with data caching if database
    writes fail due to disk being full
- Update patch:
  * systemd234.patch
* Sun Jun  2 2019 Martin Hauke <mardnh@gmx.de>
- Add Buildrequires: check-devel and enabled %%%%check section
* Mon May 13 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to version 2.2
  Fixed
  * O_CLOEXEC undeclared error when compiling with glibc older than 2.12
  * Image output --headertext wasn't being applied to some output types
  * DefaultDecimals setting wasn't controlling all outputs
  * Traffic rate for the last entry of the 5 minute resolution list wasn't
    being correctly calculated
  New
  * Detection of 32-bit / 64-bit kernel interface counters for improving
    traffic calculations in rollover situations, cfg: 64bitInterfaceCounters
  * Possibility in queries to merge data from multiple interfaces to one
    output with interface1+interface2 syntax
  * Highlight current day in top list when visible
  * Changes in interface specific detected bandwidth limits are reported
    in the log
  * UpdateInterval value is automatically adjusted during daemon startup if
    found to be too high compared to the value of MaxBandwidth
  Notes
  * Added clarification to the man page that the 'jsonversion' and
    'xmlversion' fields in the --json and --xml outputs should be seen as
    the API version and compared to the previously used version in 3rd party
    implementations for verifying compatibility
  * Default value of UpdateInterval is now 20 instead of previous 30 seconds
* Fri Apr 26 2019 Martin Hauke <mardnh@gmx.de>
- Verify source signature
- Update to version 2.1
  Fixed:
  * --oneline could segmentation fault if database had total traffic values
    set but didn't have any daily or monthly traffic (Arch bug #60588)
  * No proper error message was produced when querying interface which didn't
    exist in the database
  * Daemon:waittimesync_does_not_wait_with_new_interfaces test was failing if
    the system used a time zone with a negative numeric value
  * Traffic estimate and average rate for ongoing month was not being
    calculated correctly when MonthRotate had a value greater than 1
  * Accuracy of traffic estimate and average rate for the ongoing month could
    be slightly skewed depending on the used time zone
  New:
  * Remove possible PollInterval and UpdateInterval drift over time
  * Sync SaveInterval to full minutes
- Update to version 2.0
  Fixed:
  * Data rate calculations when using SI decimal prefixes
  * Workaround for filled arcs not drawn correctly with some versions
    of libgd (libgd/libgd#351)
  New
  * C struct dump database has been replaced with sqlite database,
  * full data import included from legacy databases of versions 1.3 - 1.18
  * User configurable data retention durations for all resolutions with
    following changed defaults:
    v1.18     v2.0
    5 minutes     n/a      576   (48 hours)
    hours          24       96   (4 days)
    days           30       62   (2 full months)
    months         12       25   (2 full years)
    years         n/a      all
    top days       10       20
  * Option to select units to use SI decimal prefixes using calculations
    with powers of 1000 (IEC and JEDEC prefixes use powers of 1024)
  * Yearly and 5 minute resolution statistics
  * Pebibyte and exbibyte support
  * Options the configure the length of each list output
  * Option to limit the length of --json and --xml outputs
  * Hourly list output replaces the hourly graph when the -h parameter is used
  * Hourly graph is accessible with -hg / --hoursgraph parameter
  * Options -b / --begin and -e / --end for specifying query time range
  * Configuration comes with ISO 8601 date formats as new defaults
  Removed
  * Weekly output
  * Merge of data from multiple interfaces to one output
  * --testkernel
  * --exportdb, use --oneline, --json or --xml instead
  * --importdb, -u / --update and related options using vnstat command
  * Old style (default in versions up to 1.7) summary layout in image output
* Thu Apr 11 2019 Dirk Stoecker <opensuse@dstoecker.de>
- Don't use new systemd service options for system below 235 (systemd234.patch)
* Wed Jan 23 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to 2.1
  2.1 / 6-Dec-2018
  * Fixed
  * --oneline could segmentation fault if database had total traffic values
    set but didn't have any daily or monthly traffic (Arch bug #60588)
  * No proper error message was produced when querying interface which didn't
    exist in the database
  * Several typos and spelling mistakes in documentation
  * Daemon:waittimesync_does_not_wait_with_new_interfaces test was failing if
    the system used a time zone with a negative numeric value
  * Traffic estimate and average rate for ongoing month was not being
    calculated correctly when MonthRotate had a value greater than 1
  * Accuracy of traffic estimate and average rate for the ongoing month could
    be slightly skewed depending on the used time zone
  * New
  * Remove possible PollInterval and UpdateInterval drift over time
  * Sync SaveInterval to full minutes
  2.0 / 21-Oct-2018
  * Fixed
  * Data rate calculations when using SI decimal prefixes
  * Workaround for filled arcs not drawn correctly with some versions
    of libgd (libgd/libgd#351)
  * New
  * C struct dump database has been replaced with sqlite database,
    full data import included from legacy databases of versions 1.3  * 1.18
  * User configurable data retention durations for all resolutions with
    following changed defaults:
    v1.18     v2.0
    5 minutes     n/a      576   (48 hours)
    hours          24       96   (4 days)
    days           30       62   (2 full months)
    months         12       25   (2 full years)
    years         n/a      all
    top days       10       20
  * Option to select units to use SI decimal prefixes using calculations
    with powers of 1000 (IEC and JEDEC prefixes use powers of 1024)
  * Yearly and 5 minute resolution statistics
  * Pebibyte and exbibyte support
  * Options the configure the length of each list output
  * Option to limit the length of --json and --xml outputs
  * Hourly list output replaces the hourly graph when the -h parameter is used
  * Hourly graph is accessible with -hg / --hoursgraph parameter
  * Options -b / --begin and -e / --end for specifying query time range
  * Configuration comes with ISO 8601 date formats as new defaults
  * Removed
  * Weekly output
  * Merge of data from multiple interfaces to one output
  * --testkernel
  * --exportdb, use --oneline, --json or --xml instead
  * --importdb, -u / --update and related options using vnstat command
  * Old style (default in versions up to 1.7) summary layout in image output
* Wed May 23 2018 liedke@rz.uni-mannheim.de
- Update to 1.18
  * Fix: Misspellings, compiler warnings and possible error situations
    (pull requests by Christian Göttsche)
  * Hardening added to examples/systemd/vnstat.service
    (pull request by Christian Göttsche)
  * Add RTC sanity check and sync wait to daemon startup, the possible wait
    duration can be configured using the TimeSyncWait keyword
  * Add optional parameter to --oneline output for forcing fields to output
    in bytes
  * Add --json support for -l / --live and -tr outputs
  * Number of decimals used in outputs can be configured using DefaultDecimals
    and HourlyDecimals
  * Add section separators for improving readabilty of the vnstat -h output,
    configurable using HourlySectionStyle
* Tue Feb 21 2017 liedke@rz.uni-mannheim.de
- Update to 1.17:
  * Fix: --importdb was creating invalid databases since version
    1.15
  * Fix: console output was being buffered which resulted in lack
    of output in at least systemd log
  * Add cross-compilation detection and improve install-data-hook
    to not assume that the binaries can be executed in the host
    system
- Update to 1.16:
  * Fix: traffic rate calculation, SI decimal prefixes were shown
    but calculation was done for IEC binary prefixes
  * Add option for configure to disable image output support even
    if required library is available, improve library detection
  * Add selection between SI decimal prefixes (kbit/s...) (default)
    and IEC binary prefixes (Kibit/s...) for traffic rate using
    RateUnitMode keyword in configuration file
  * Improve database handling resilience
  * Inherit database file ownership from database directory if
    UpdateFileOwner configuration option is enabled (default:
    enabled) when adding new interfaces for monitoring as root.
    This solves database file ownership mismatches when the daemon
    is started as a non-root user and an interface gets added for
    monitoring with a sudo command as root
  * Improve user guidance in error situations related to the
    configured default interface
* Sat Mar  5 2016 sor.alexei@meowr.ru
- Update to 1.15:
  * Fix: XML output had extra commas, broken since previous version.
  * Fix: unintended shared pointer modification in mosecs()
    sometimes resulted in wrong month name to be shown for the
    current month.
  * Fix possible buffer overflow in /proc/net/dev parsing, requires
    corrupted content in /proc/net/dev or use of address sanitiser.
  * Use ANSI escape codes in -l and -tr modes for cursor location
    manipulation instead of printing backspaces, hide cursor while
    output is active.
  * Improve database import robustness.
  * Improve support for Asian UTF-8 date strings.
  * Replace hand written Makefiles with autotools.
  * Add --alwaysadd parameter to daemon for allowing automatic
    addition of interfaces even if the database directory was
    populated during startup.
* Tue Aug 18 2015 Mathias.Homann@opensuse.org
- Fix: vnstati was missing from build, needed for vnstat-cgi to function.
* Tue Aug  4 2015 sor.alexei@meowr.ru
- Update to 1.14 (changes since 1.11):
  * Fix memory allocation when zero interfaces are available,
    also lo needed to be missing in order to trigger this leak.
  * Fix rebuild total indexing.
  * Fix some error situations that could leave database file open
    until the end of command execution
  * Fix: Live traffic meter occasionally showing higher minimum
    than average in end statistics.
  * Fix setting locale when none is specified in config.
  * Fix cppcheck findings.
  * Improve traffic meter output accuracy.
  * Add tests and debug compilation target.
  * Remove use of -D parameter in Makefile install commands in
    order to improve cross-compilation support.
  * Set CFLAGS in Makefiles only when not already defined.
  * Add support for database import from text file (--importdb).
  * Rename --dumpdb to --exportdb.
  * Add example systemd service file.
  * Use ISO YYYY-MM-DD date format timestamps if logfile is used.
  * Improve daemon startup prints.
  * Add parameters for changing daemon process user and group.
  * Add example upstart job configuration file.
  * Create database, pid and log dirs during daemon startup if
    necessary.
  * Update ownership of database, log and pid files if needed
    during daemon startup if started as root and configured to
    change process user and group.
  * Remove cron update related example files and documentation, the
    cron update method should be considered as deprecated.
  * --create parameter for database creation.
  * Dynamic unit selection in hourly output instead of being fixed
    to KiB.
  * New options in image output (vnstati):
    + -nl / --nolegend for hiding the rx/tx legend;
    + --altdate for using alternative date and time text location;
    + --headertext for using custom text string in image header;
    section.
  * Add legend to hourly output image.
  * Add option for content alignment and page background colour to
    vnstat.cgi.
  * Document keyword value ranges in configuration file man page.
  * Import Makefile improvements from OpenBSD.
  * Automatic interface bandwidth detection, BandwidthDetection in
    config, default fallback value MaxBandwidth changed from 100 to
    1000.
  * JSON output (--json), vnstat-json.cgi and vnstat-json.php
    examples provided in the 'examples' directory
  * Drop support for over 10 year old database formats
    (versions 1.0 - 1.2).
  * Fix: JSON output syntax during first day of newly created
    databases.
  * Fix: field padding when using UTF-8 locale.
  * Add optional mode parameter to --json and --xml for limiting
    the output to only selected information.
- Add a systemd service.
- Remove vnstat-cron.patch and cronjob: upstream considers it
  deprecated.
- Remove vnstat-help_script.patch: fixed upstream.
- Only recommend Apache for vnstat-cgi: there are other HTTP
  servers.
- Spec cleanup.
* Sun Aug 10 2014 chris+dev@any.mx
- removed '-u' parameter from init.d script to actually being able to start the daemon
* Wed Jul 31 2013 cwh@suse.com
- Fixed spec file (removed lost pach files)
* Sun Jul  7 2013 lars@linux-schulserver.de
- remove the '-o' option in useradd: -o is useless without -u and
  newer versions of pwdutils/shadowutils fail on this now
- specfile cleanup (added license header and cron dependency)
- fix address of Free Software Foundation in init script
* Mon Feb  4 2013 lars@linux-schulserver.de
- update to 1.11:
  * Fix: Memory allocation was miscalculated when creating interface list from
    /sys/class/net when /proc/net/dev wasn't available which in turn could
    crash the daemon
  * Fix: Daemon database cache could remain empty after a -HUP signal
  * Fix: Don't make temp directory in vnstat.cgi writable for everyone
  * Import GNU/kFreeBSD support from Debian
  (#608963, patch by Mats Erik Andersson)
  * Remove usage of GNU only '-D' option for install for BSD in Makefile
  * The daemon now automatically creates databases for available interfaces
  if no databases are found during startup
* Mon Feb  4 2013 lars@linux-schulserver.de
- prevent cron from writing a syslog message about the vnstat call
* Sat Aug 21 2010 highwaystar.ru@gmail.com
- update to 1.10:
  * Fix: Buffer overflow was possible in hourly image output when RateUnit=1
  and HourlyRate=1
  * Fix: Minor memory leak was possible in the handling of HUP signal in daemon
  * Fix: Graphical elements weren't correctly aligned in summary image
  when header wasn't visible (-nh)
  * Fix: --delete didn't work
  * Possibility to merge statistics from several databases and save
  the end result to a new database (--mergesaved)
  * Added validation of database cache in daemon in order to be more robust
  in case of system memory corruption
  * Support for --style to -l (live mode)
  * Alternative print mode to -l (live mode) with optional parameter
  * Present options and elements in man pages in alphabetical order
  * Code cleanup
- changes in 1.9:
  * Fix: TrafficlessDays configuration option was enabled when set to zero
  when it should have been disabled
  * Fix: MonthRotate setting was getting ignored for the first month if
  the database is created when day of month < MonthRotate value
  * Configurable summary layout in image output (1.7 <> 1.8 layouts)
  * --oneline, a simple parseable one line output
  * --transparent for setting image background transparency from the
  command line
  * --delete for deleting databases and stopping monitoring, doesn't require
  restarting the daemon
  * A database write can be configure to occur after interface status changes
  * Different database write interval can be configure to be used when
  all monitored interfaces are offline
  * Better configurability for the content of outputs, including a narrow
  output for space limited terminals (OutputStyle and --style)
  * Code cleanup
  * New configuration file settings:
  OutputStyle, SummaryLayout, SummaryRate, SaveOnStatusChange,
  OfflineSaveInterval
* Wed Aug 19 2009 poeml@suse.de
- fix segfault caused by vnstat-limits+su.patch.
  vnstat-limits+su+fix.patch added.
* Sun Aug  2 2009 pascal.bleser@opensuse.org
- update to 1.8:
  * makes averaged traffic rates visible
  * adds monthly traffic to the summary
  * supports merging data from multiple interfaces to one output
  * dates are now formatted according to the system locale setting by default
* Tue May 26 2009 poeml@novell.com
- change ownership also of existing backup files of the database
- ignore '.' and '..' when modifying files -- the previous method could change
  the ownership of /var/lib...
* Tue May 26 2009 poeml@novell.com
- move creation of "vnstat" user from %%post to %%pre, so that it happens before
  files are installed
- make vnstat a system user and create a separate group "vnstat" for it
- prerequire the tools needed for the pre/post scripts
- change ownership of existing databases from root to vnstat user, when updating
* Mon May 25 2009 pascal.bleser@opensuse.org
- don't filter out br interfaces, thanks to Dmitry Mittov for noticing
* Fri May 15 2009 pascal.bleser@opensuse.org
- add a little frontend script to create the vnstat databases as the vnstat user
- add patch to vnstat help output to tell to use the script to create a database
* Fri May 15 2009 pascal.bleser@opensuse.org
- install hook scripts into /etc/ppp/*.d/
- install CGI + patch heavily, using a subpackage vnstat-cgi
- add support for vnstatd (added in 1.7) with init script, vnstat user, and an improved cron job file
- add switch user support during daemonization to vnstatd
- fix all compile warnings
- update to 1.7:
  * Fix: Timezone changes shouldn't cause a flood of errors anymore
  * Fix: MonthRotate value in config wasn't used
  * Fix: Unreadable configuration file doesn't cause a segmentation fault
  * Fix: /proc/net/dev parser didn't see the difference between eth10 and eth1
  * Fix: Updating a database from two of more processes at the same time was able to sometimes cause data loss
  * Fix: Estimates are calculated based on last database update
  * Fix: Each interface update had a possibility of losing 1023 bytes of traffic at most due to improper rounding
  * Daemon support as alternative for cron based updates
  * PNG image output (hourly rate based on patch by Sergio Ammirata)
  * XML output
  * Diskspace check can be disabled from configuration file
  * IEC standard prefixes (KiB/MiB/GiB/TiB)
  * List of available interfaces if wrong of unavailable interface is selected
* Wed Feb 20 2008 poeml@suse.de
- update to 1.6:
  1.6 / 1-Jan-08
  - Fix: Segmentation fault when environment variable "HOME" wasn't defined,
    this broke most CGI and PHP scripts that used vnStat
  - Support for /sys/class/net/* if /proc/net/dev is unavailable
  - Config file parser redesigned
  - --config parameter for selecting config file
  - Consistent exit status for all operations (0 for success, 1 for error)
  - Improved file locking
  - Man page restrictions paragraph updated
  - Minor non-visible fixes and code cleanup
  1.5 / 3-Dec-07
  - Fix: compile time warnings solved
  - Fix: kernel test is now more verbose
  - Fix: more informative error messages
  - Fix: possible division by zero for traffic estimates right after midnight
  - Fix: interface names longer than 6 chars (patch by Jan Schmidle)
  - Realtime transfer rate mode
  - Automatic 32bit/64bit counter detection
  - Config file support
  - Internal database backups and locking
  - More visuals in outputs
  - Adaptive units (kB, MB, GB, TB)
  - Possibility to sync counters without counting traffic
  - Maximum bandwidth of interfaces can be set
* Wed Feb 20 2008 poeml@suse.de
- re-import the package sources from 10.1, they got lost
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jul  2 2005 hvogel@suse.de
- make use of optflags
* Mon Jun  6 2005 hvogel@suse.de
- add suse.de- prefix to the cron script
* Tue Feb 15 2005 hvogel@suse.de
- Use "-" in cron file to suppress syslog message
* Tue Feb  8 2005 hvogel@suse.de
- New Package, Version 1.4
